;; Generated package description from bicep-ts-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "bicep-ts-mode" "0.1.4.0.20260720.83" "tree-sitter support for Bicep" 'nil :commit "f59889ab175bb309b474b82ca2cde4e791fe2677" :authors '(("Jostein Kjønigsen" . "jostein@kjonigsen.net")) :maintainer '("Jostein Kjønigsen" . "jostein@kjonigsen.net") :keywords '("bicep" "languages" "tree-sitter") :url "https://github.com/josteink/bicep-ts-mode")
